use std::net::{Ipv4Addr, Ipv6Addr};
use std::fmt;

pub enum RData {
    A(A),
    Aaaa(Aaaa),
    Cname(Cname),
    Mx(Mx),
    Ns(Ns),
    Ptr(Ptr),
    Soa(Soa),
    Srv(Srv),
    Txt(Txt),
}

pub struct Name {
    name: String
}

impl Name {
    pub fn new(name: String) -> Self {
        Name {
            name,
        }
    }
}

impl fmt::Display for Name {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "{}", self.name)
    }
}

pub struct A {
    pub address: Ipv4Addr,
}

pub struct Aaaa {
    pub address: Ipv6Addr,
}

pub struct Cname {
    pub target: Name,
}

pub struct Mx {
    pub preference: u16,
    pub mail_exchanger: Name,
}

pub struct Ns {
    pub target: Name,
}

pub struct Ptr {
    pub target: Name,
}

pub struct Soa {
    pub primary_server: Name,
    pub maintainer: Name,
    pub refresh: u32,
    pub retry: u32,
    pub expire: u32,
    pub minimum: u32,
    pub serial: u32,
}

pub struct Srv {
    pub server: Name,
    pub port: u16,
    pub priority: u16,
    pub weight: u16,
}

pub struct Txt {
    pub text: Vec<u8>,
}
